# dont echo commands
library("outliers")
#options(echo=F)

library("extrafont")



setEPS()
tap_rep <- read.table("./FINAL_output_ALL_Tapidor_v6.3_OUT_all_regions_rnc_fixed_merged_FILTERED_50BP.out")
dar_rep <- read.table("./FINAL_output_ALL_placed_v81_OUT_all_regions_rnc_fixed_merged_FILTERED_50BP.out")
tap_rep <- cbind(tap_rep, tap_rep$V3-tap_rep$V2)
dar_rep <- cbind(dar_rep, dar_rep$V3-dar_rep$V2)
names(tap_rep) <- c("Chromosome", "Start", "End", "Length")
names(dar_rep) <- c("Chromosome", "Start", "End", "Length")

# first, make the tables by chromosome
rep_tap_chrom_count <- as.data.frame(table(tap_rep$Chromosome))
rep_dar_chrom_count <- as.data.frame(table(dar_rep$Chromosome))
rep_dar_chrom_sizes <- as.data.frame(table(dar_rep$Length))

write.csv(rep_dar_chrom_count, "Darmor_repetitive_count_by_chromosome.csv")
write.csv(rep_tap_chrom_count, "Tapidor_repetitive_count_by_chromosome.csv")


## NOW PLOT

cairo_ps( "boxplotRepetitiveCounts.eps")
boxplot(rep_dar_chrom_count$Freq ,rep_tap_chrom_count$Freq, names=c("Darmor", "Tapidor"), fontfamily='Arial')
garbage <- dev.off()
tiff( "boxplotRepetitiveCounts.tiff", height=3000, width=3000, res=500)
boxplot(rep_dar_chrom_count$Freq, rep_tap_chrom_count$Freq, names=c("Darmor", "Tapidor"), fontfamily='Arial')
garbage <- dev.off()

# and get some stats
print("-----------------------------------------------------")
print("Wilcoxon test for repetitive counts, Darmor vs Tapidor")
wilcox.test(rep_dar_chrom_count$Freq, rep_tap_chrom_count$Freq, paired=FALSE)
print(paste("There are ", sum(rep_dar_chrom_count$Freq), " repetitive regions in Darmor and ", sum(rep_tap_chrom_count$Freq), " repetitive regions in Tapidor"))
print("-----------------------------------------------------")
# do we have outliers?
print("Grubbs test repetitive chrom count, Darmor")
grubbs.test(rep_dar_chrom_count$Freq)
print("Grubbs test repetitive chrom count, Tapidor")
grubbs.test(rep_tap_chrom_count$Freq)
print("Grubbs test both together")
grubbs.test(c(rep_tap_chrom_count$Freq, rep_dar_chrom_count$Freq))

## now the same for collapsed files

tap_coll <- read.table("./FINAL_output_ALL_Tapidor_v6.3_OUT_all_regions_coll_fixed_merged_FILTERED_50BP.out")
dar_coll <- read.table("./FINAL_output_ALL_placed_v81_OUT_all_regions_coll_fixed_merged_FILTERED_50BP.out")
tap_coll <- cbind(tap_coll, tap_coll$V3-tap_coll$V2)
dar_coll <- cbind(dar_coll, dar_coll$V3-dar_coll$V2)
names(tap_coll) <- c("Chromosome", "Start", "End", "Length")
names(dar_coll) <- c("Chromosome", "Start", "End", "Length")

## first, make the tables by chromosome
coll_tap_chrom_count <- as.data.frame(table(tap_coll$Chromosome))
coll_dar_chrom_count <- as.data.frame(table(dar_coll$Chromosome))

write.csv(coll_dar_chrom_count, "Darmor_collapsed_count_by_chromosome.csv")
write.csv(coll_tap_chrom_count, "Tapidor_collapsed_count_by_chromosome.csv")

## NOW PLOT

cairo_ps( "boxplotcollapsedCounts.eps")
boxplot(coll_dar_chrom_count$Freq, coll_tap_chrom_count$Freq, names=c("Darmor", "Tapidor"), fontfamily='Arial')
garbage <- dev.off()
tiff( "boxplotcollapsedCounts.tiff", height=3000, width=3000, res=500)
boxplot(coll_dar_chrom_count$Freq, coll_tap_chrom_count$Freq, names=c("Darmor", "Tapidor"), fontfamily='Arial')
garbage <- dev.off()

# and get some stats
print("-----------------------------------------------------")
print("Wilcoxon test for collapsed counts, Darmor vs Tapidor")
wilcox.test(coll_dar_chrom_count$Freq, coll_tap_chrom_count$Freq, paired=FALSE)
print(paste("There are ", sum(coll_dar_chrom_count$Freq), " collapsed regions in Darmor and ", sum(coll_tap_chrom_count$Freq), " collapsed regions in Tapidor"))
print("-----------------------------------------------------")
# do we have outliers?
print("Grubbs test collapsed chrom count, Darmor")
grubbs.test(coll_dar_chrom_count$Freq)
print("Grubbs test collapsed chrom count, Tapidor")
grubbs.test(coll_tap_chrom_count$Freq)
print("Grubbs test both together")
grubbs.test(c(coll_tap_chrom_count$Freq, coll_dar_chrom_count$Freq))

